@@ -22,7 +22,7 @@ void TestStrokeOpacity::checkStrokeOpacity_data()
     QTest::addColumn<int>("backendType");
 
     QTest::newRow("splash") << (int)Poppler::Document::SplashBackend;
-    QTest::newRow("qpainter") << (int)Poppler::Document::ArthurBackend;
+    QTest::newRow("qpainter") << (int)Poppler::Document::QPainterBackend;
 }
 
 void TestStrokeOpacity::checkStrokeOpacity()
